Ultimeter - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Ultimeter

The Ultimeter driver operates the Ultimeter in Data Logger Mode, which results in sensor readings every 1/2 second or so.

The Ultimeter driver ignores the maximum, minimum, and average values recorded by the station.

## Configuring with `wee_device`

The Ultimeter stations cannot be configured with the utility `wee_device`.

## Station data

The following table shows which data are provided by the station hardware and which are calculated by WeeWX.

Ultimeter station data
Database Field | Observation | Loop | Archive
barometer2 | barometer | H |
pressure2 |  | S |
altimeter2 |  | S |
inTemp2 | temperature_in | H |
outTemp | temperature_out | H |
inHumidity2 | humidity_in | H |
outHumidity | humidity_out | H |
windSpeed | wind_speed | H |
windDir | wind_dir | H |
rain1 | rain | D |
| rain_total | H |
rainRate1 |  | S |
dewpoint |  | S |
windchill |  | S |
heatindex |  | S |

1 The rain and rainRate are available only on stations with the optional rain sensor.

2 Pressure, inside temperature, and inside humidity data are not available on all types of Ultimeter stations.

H indicates data provided by Hardware
D indicates data calculated by the Driver
S indicates data calculated by the StdWXCalculate Service